@@ -5,15 +5,20 @@ OC.L10N.register(
     "Talk" : "Paroli",
     "Guest" : "Gasto",
     "Message deleted by author" : "Mesaĝo estas forigita per aǔtoro",
+    "Administration" : "Administrado",
+    "System" : "Sistemo",
     "Talk conversations" : "Buŝaj konversacioj",
     "Talk to %s" : "Paroli al %s",
     "File is too big" : "Dosiero tro grandas",
     "Invalid file provided" : "Nevalida dosiero provizita",
     "Invalid image" : "Nevalida bildo",
     "Unknown filetype" : "Nekonata dosiertipo",
+    "Description" : "Priskribo",
     "Dismiss notification" : "Forsendi sciigon",
     "Accept" : "Akcepti",
     "Decline" : "Malakcepti",
+    "New message" : "Nova mesaĝo",
+    "Notification" : "Atentigo",
     "error" : "eraro",
     "Avatar image is not square" : "Avatarbildo ne estas kvadrata",
     "Andorra" : "Andoro",
@@ -261,7 +266,6 @@ OC.L10N.register(
     "Limit to groups" : "Limigi al grupoj",
     "Disabled" : "Malŝaltita",
     "Name" : "Nomo",
-    "Description" : "Priskribo",
     "Beta" : "Beta",
     "Enable encryption" : "Ŝalti ĉifradon",
     "Pending" : "Pritraktota",
@@ -278,7 +282,6 @@ OC.L10N.register(
     "Back" : "Antaŭen",
     "Cancel" : "Nuligi",
     "Loading …" : "Ŝargado...",
-    "No upcoming events" : "Neniuj venontaj eventoj",
     "From" : "De",
     "To" : "Al",
     "Calendar" : "Kalendaro",
@@ -286,7 +289,9 @@ OC.L10N.register(
     "Save" : "Konservi",
     "No results" : "Neniu rezulto",
     "Done" : "Farita",
+    "Grid view" : "Krada vido",
     "Copy link" : "Kopii ligilon",
+    "None" : "Nenio",
     "You" : "Vi",
     "Collapse" : "Maletendi",
     "Favorite" : "Pliŝatata",
@@ -305,12 +310,12 @@ OC.L10N.register(
     "Delete" : "Forigi",
     "Log content" : "Protokolenhavo",
     "Notifications" : "Sciigoj",
+    "Join" : "Aliĝi",
     "Log in" : "Ensaluti",
     "Remove from favorites" : "Forigi el pliŝataĵoj",
     "Add to favorites" : "Aldoni al pliŝataĵoj",
     "Users" : "Uzantoj",
     "Groups" : "Grupoj",
-    "None" : "Nenio",
     "Devices" : "Aparatoj",
     "Upload" : "Alŝuti",
     "Files" : "Dosieroj",
@@ -325,7 +330,6 @@ OC.L10N.register(
     "Send" : "Sendi",
     "Settings" : "Agordoj",
     "Anonymous poll" : "Enketo sennoma",
-    "Join" : "Aliĝi",
     "guest" : "gasto",
     "Add users or groups" : "Add users or groups",
     "Searching …" : "Serĉado ...",
@@ -335,7 +339,9 @@ OC.L10N.register(
     "Performance" : "Rendimento",
     "Keyboard shortcuts" : "Fulmoklavoj",
     "Search" : "Serĉi",
-    "Grid view" : "Krada vido",
+    "More actions" : "Pliaj agoj",
+    "Default" : "Defaŭlta",
+    "Keep" : "Konservi",
     "Select a region" : "Elekti regionon",
     "Submit" : "Sendi",
     "User" : "Uzanto",
@@ -349,14 +355,11 @@ OC.L10N.register(
     "Other" : "Alia",
     "Group" : "Grupo",
     "Please reload the page." : "Bonvolu reŝargi la paĝon.",
-    "Default" : "Defaŭlta",
     "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
     "Android app" : "Android-aplikaĵo",
     "iOS app" : "iOS-aplikaĵo",
     "__language_name__" : "Esperanto",
     "Tasks" : "Taskoj",
-    "Loading" : "Ŝargado",
-    "Close" : "Malfermi",
-    "Password protect" : "Protekti per pasvorto"
+    "Close" : "Malfermi"
 },
 "nplurals=2; plural=(n != 1);");
