@@ -15,6 +15,7 @@ OC.L10N.register(
     "Dismiss notification" : "Eliminar notificación",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
+    "New message" : "Mensaje nuevo",
     "Open settings" : "Abrir opciones",
     "error" : "error",
     "Messages" : "Mensajes",
@@ -55,9 +56,11 @@ OC.L10N.register(
     "Save" : "Guardar",
     "No results" : "Sin resultados",
     "Done" : "Terminado",
+    "Grid view" : "Vista de cuadrícula",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "Copy link" : "Copiar enlace",
     "Mute audio" : "Silenciar audio",
+    "None" : "Ninguno",
     "Disable video" : "Deshabilitar video",
     "You" : "Usted",
     "Collapse" : "Colapsar",
@@ -86,7 +89,6 @@ OC.L10N.register(
     "Add to favorites" : "Agregar a favoritos",
     "Users" : "Ususarios",
     "Groups" : "Grupos",
-    "None" : "Ninguno",
     "Devices" : "Dispositivos",
     "Upload" : "Cargar",
     "Files" : "Archivos",
@@ -111,6 +113,7 @@ OC.L10N.register(
     "Privacy" : "Privacidad",
     "Keyboard shortcuts" : "Atajos de teclado",
     "Search" : "Buscar",
+    "Default" : "Predeterminado",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir su pantalla. ",
@@ -118,7 +121,7 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
     "Show your screen" : "Mostrar su pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
-    "Grid view" : "Vista de cuadrícula",
+    "Keep" : "Mantener",
     "Submit" : "Enviar",
     "User" : "Usuario",
     "Password" : "Contraseña",
@@ -134,7 +137,6 @@ OC.L10N.register(
     "Please reload the page." : "Favor de volver a cargar la página.",
     "Do not disturb" : "No molestar",
     "Away" : "Lejos",
-    "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
     "WebRTC is not supported in your browser" : "WebRTC no está soportado en su navegador",
