@@ -12,6 +12,7 @@ OC.L10N.register(
     "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
     "Talk" : "Hablar",
     "Guest" : "Invitado",
+    "Message deleted by author" : "Mensaje borrado por el autor",
     "Administration" : "Administración",
     "System" : "Sistema",
     "Talk to %s" : "Hablar con %s",
@@ -22,6 +23,7 @@ OC.L10N.register(
     "Description" : "Descripción",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
+    "New message" : "Mensaje nuevo",
     "Join call" : "Unirse a la llamada",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
@@ -66,12 +68,14 @@ OC.L10N.register(
     "Attendees" : "Asistentes",
     "Save" : "Guardar",
     "No results" : "No hay resultados",
+    "Grid view" : "Vista de cuadrícula",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "Copy link" : "Copiar liga",
     "Mute audio" : "Silenciar audio",
+    "None" : "Ninguno",
     "Disable video" : "Deshabilitar video",
     "Enable video" : "Habilitar el video",
     "You" : "Tú",
@@ -97,7 +101,6 @@ OC.L10N.register(
     "Add to favorites" : "Agregar a tus favoritos",
     "Users" : "Ususarios",
     "Groups" : "Grupos",
-    "None" : "Ninguno",
     "Devices" : "Dispositivos",
     "No audio" : "Sin audio",
     "Upload" : "Cargar",
@@ -126,6 +129,8 @@ OC.L10N.register(
     "Privacy" : "Privacidad",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
+    "More actions" : "Más acciones",
+    "Default" : "Predeterminado",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -135,7 +140,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
-    "Grid view" : "Vista de cuadrícula",
     "Submit" : "Enviar",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
     "User" : "Usuario",
@@ -150,7 +154,6 @@ OC.L10N.register(
     "Group" : "Grupo",
     "Please reload the page." : "Por favor vuelve a cargar la página.",
     "Away" : "Ausente",
-    "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Please move your setup to HTTPS" : "Por favor cambia tu configuración a HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
