@@ -676,6 +676,15 @@ OC.L10N.register(
     "Search participants" : "Cerca partecipanti",
     "No results" : "Nessun risultato",
     "Done" : "Completato",
+    "Raise hand" : "Alza la mano",
+    "Raise hand (R)" : "Alza la mano (R)",
+    "Lower hand" : "Abbassa la mano",
+    "Lower hand (R)" : "Abbassa la mano (R)",
+    "Exit full screen (F)" : "Esci dalla modalità a schermo intero (F)",
+    "Full screen (F)" : "Schermo intero (F)",
+    "Speaker view" : "Visualizzazione oratore",
+    "Grid view" : "Vista Griglia",
+    "You need to close a dialog to toggle full screen" : "È necessario chiudere una finestra per passare alla modalità a schermo intero",
     "This conversation is read-only" : "Questa conversazione è in sola lettura",
     "{nickName} raised their hand." : "{nickName} ha alzato la mano.",
     "A participant raised their hand." : "Un partecipante ha alzato la mano.",
@@ -694,6 +703,7 @@ OC.L10N.register(
     "Mute audio (M)" : "Silenzia audio (M)",
     "Unmute audio" : "Rimuovi silenzio audio",
     "Unmute audio (M)" : "Rimuovi silenzio audio (M)",
+    "None" : "Nessuno",
     "Access to camera was denied" : "L'accesso alla fotocamera è stato negato",
     "Error while accessing camera: It is likely in use by another program" : "Errore durante l'accesso alla fotocamera: È probabile che sia utilizzata da un altro programma",
     "Error while accessing camera" : "Errore durante l'accesso alla fotocamera",
@@ -842,12 +852,12 @@ OC.L10N.register(
     "The meeting will start soon" : "La riunione inizierà presto",
     "This meeting is scheduled for {startTime}" : "Questa riunione è programmata per {startTime}",
     "You are currently waiting in the lobby" : "Stai attualmente aspettando nell'ingresso",
-    "None" : "Nessuno",
     "Select microphone" : "Seleziona microfono",
     "No microphone available" : "Nessun microfono disponibile",
     "Select camera" : "Seleziona fotocamera",
     "No camera available" : "Nessuna fotocamera disponibile",
     "Select a device" : "Seleziona un dispositivo",
+    "Test" : "Prova",
     "Devices" : "Dispositivi",
     "No audio" : "Nessun audio",
     "No camera" : "Nessuna fotocamera",
@@ -856,12 +866,11 @@ OC.L10N.register(
     "Access to microphone was denied" : "L'accesso al microfono è stato negato",
     "Error while accessing microphone" : "Errore durante l'accesso al microfono",
     "Access to camera is only possible with HTTPS" : "L'accesso alla fotocamera è possibile solo con HTTPS",
-    "Call without notification" : "Chiama senza notifica",
+    "Select a file" : "Seleziona un file",
     "Invalid path selected" : "Percorso selezionato non valido",
     "Blur" : "Sfocatura",
     "Upload" : "Carica",
     "Files" : "File",
-    "Select a file" : "Seleziona un file",
     "Message read by everyone who shares their reading status" : "Messaggio letto da tutti coloro che condividono il proprio stato di lettura",
     "Message sent" : "Messaggio inviato",
     "Deleting message" : "Eliminazione del messaggio",
@@ -921,8 +930,8 @@ OC.L10N.register(
     "No permission to post messages in this conversation" : "Nessun permesso per pubblicare messaggi in questa conversazione",
     "Joining conversation …" : "Partecipazione alla conversazione...",
     "Send message" : "Invia messaggio",
-    "Add emoji" : "Aggiungi emoji",
     "File to share" : "File da condividere",
+    "Add emoji" : "Aggiungi emoji",
     "Share from Files" : "Condividi da File",
     "Share files to the conversation" : "Condividi file nella conversazione",
     "Upload from device" : "Carica dal dispositivo",
@@ -1003,11 +1012,13 @@ OC.L10N.register(
     "Load more results" : "Mostra altri risultati",
     "Projects" : "Progetti",
     "No shared items" : "Nessun elemento condiviso",
+    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
     "Link to a conversation" : "Collega a una conversazione",
     "Search conversations or users" : "Cerca conversazioni o utenti",
     "Select conversation" : "Seleziona conversazione",
     "Edit display name" : "Modifica nome visualizzato",
     "Choose the folder in which attachments should be saved." : "Scegli la cartella in cui salvare gli allegati.",
+    "Select location for attachments" : "Seleziona la posizione per gli allegati",
     "Error while setting attachment folder" : "Errore durante l'impostazione della cartella degli allegati",
     "Your privacy setting has been saved" : "Le tue impostazioni di riservatezza sono state salvate",
     "Error while setting read status privacy" : "Errore durante l'impostazione della riservatezza dello stato di lettura",
@@ -1016,7 +1027,6 @@ OC.L10N.register(
     "Error while saving sounds setting" : "Errore durante il salvataggio dell'impostazione dei suoni",
     "Attachments folder" : "Cartella degli allegati",
     "Browse …" : "Sfoglia ...",
-    "Select location for attachments" : "Seleziona la posizione per gli allegati",
     "Appearance" : "Aspetto",
     "Privacy" : "Riservatezza",
     "Share my read-status and show the read-status of others" : "Condividi il mio stato di lettura e mostra lo stato di lettura degli altri",
@@ -1039,11 +1049,11 @@ OC.L10N.register(
     "Space bar" : "Barra spaziatrice",
     "Push to talk or push to mute" : "Premi per parlare o premi per silenziare",
     "Raise or lower hand" : "Alza o abbassa la mano",
+    "More actions" : "Altre azioni",
     "Start call" : "Inizia chiamata",
     "You will be able to join the call only after a moderator starts it." : "Potrai unirti alla chiamata solo dopo che un moderatore l'abbia avviata.",
     "Recording" : "Registrazione",
-    "Disable background blur" : "Disattiva la sfocatura dello sfondo",
-    "Blur background" : "Sfocatura dello sfondo",
+    "Default" : "Predefinita",
     "You are not allowed to enable screensharing" : "Non sei autorizzato ad abilitare la condivisione dello schermo",
     "No screensharing" : "Nessuna condivisione dello schermo",
     "Screensharing options" : "Opzioni di condivisione dello schermo",
@@ -1056,6 +1066,7 @@ OC.L10N.register(
     "Bad sent audio and video quality." : "Qualità dell'audio e del video inviate non corrette.",
     "Bad sent audio quality." : "Qualità audio inviata non corretta.",
     "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di vedere il tuo schermo. Per migliorare la situazione prova, a disabilitare la sfocatura dello sfondo o il tuo video mentre fai una condivisione dello schermo.",
+    "Disable background blur" : "Disattiva la sfocatura dello sfondo",
     "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di vedere il tuo schermo. Per migliorare la situazione, prova a disabilitare il tuo video durante una condivisione dello schermo.",
     "Your internet connection or computer are busy and other participants might be unable to see your screen." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di vedere il tuo schermo.",
     "Your internet connection or computer are busy and other participants might be unable to see you." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di vederti.",
@@ -1075,15 +1086,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Si è verificato un errore durante l'avvio della condivisione dello schermo.",
     "Show your screen" : "Mostra il tuo schermo",
     "Stop screensharing" : "Ferma la condivisione dello schermo",
-    "Exit full screen (F)" : "Esci dalla modalità a schermo intero (F)",
-    "Full screen (F)" : "Schermo intero (F)",
-    "Speaker view" : "Visualizzazione oratore",
-    "Grid view" : "Vista Griglia",
-    "Raise hand" : "Alza la mano",
-    "Raise hand (R)" : "Alza la mano (R)",
-    "Lower hand" : "Abbassa la mano",
-    "Lower hand (R)" : "Abbassa la mano (R)",
-    "You need to close a dialog to toggle full screen" : "È necessario chiudere una finestra per passare alla modalità a schermo intero",
     "Mute others" : "Silenzia gli altri",
     "Toggle full screen" : "Attiva schermo intero",
     "Select a region" : "Seleziona una regione",
@@ -1155,7 +1157,6 @@ OC.L10N.register(
     "Group" : "Gruppo",
     "Team" : "Team",
     "You: {lastMessage}" : "Tu: {lastMessage}",
-    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Stai tentando di partecipare a una conversazione mentre hai una sessione attiva in un'altra finestra o dispositivo. Questo non è attualmente supportato da Nextcloud Talk. Che cosa vuoi fare?",
     "Leave this page" : "Abbandona questa pagina",
     "Join here" : "Unisciti qui",
@@ -1188,7 +1189,6 @@ OC.L10N.register(
     "Please reload the page." : "Ricarica la pagina.",
     "Do not disturb" : "Non disturbare",
     "Away" : "Assente",
-    "Default" : "Predefinita",
     "Microphone {number}" : "Microfono {number}",
     "Camera {number}" : "Fotocamera {number}",
     "Speaker {number}" : "Altoparlante {number}",
@@ -1218,9 +1218,11 @@ OC.L10N.register(
     "{user} invited you to a private conversation" : "{user} ti ha invitato a una conversazione privata",
     "Always show the device preview screen before joining a call in this conversation." : "Mostra sempre la schermata di anteprima del dispositivo prima di partecipare a una chiamata in questa conversazione.",
     "Copy conversation link" : "Copia collegamento della conversazione",
+    "Call without notification" : "Chiama senza notifica",
     "Close" : "Chiudi",
     "Choose devices" : "Scegli i dispositivi",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk è stato aggiornato, devi ricaricare la pagina prima di poter iniziare o partecipare a una chiamata.",
+    "Blur background" : "Sfocatura dello sfondo",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk è stato aggiornato, ricarica la pagina",
     "An error happened when trying to share your file" : "Si è verificato un errore durante il tentativo di condividere il tuo file",
     "Failed to join the conversation. Try to reload the page." : "Partecipazione alla conversazione non riuscita. Prova a ricaricare la pagina.",
