@@ -21,6 +21,8 @@ OC.L10N.register(
     "You created the conversation" : "Tu izveidoji sarunu",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pārdēvēja sarunu no \"%1$s\" uz \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pārdēvējāt sarunu no \"%1$s\" uz \"%2$s\"",
+    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Pārvaldītājs pārdēvēja sarunu no \"%1$s\" uz \"%2$s\"",
+    "You removed the description" : "Tu noņēmi aprakstu",
     "You started a call" : "Jūs sākāt zvanu",
     "{actor} started a call" : "{actor} sācis zvanu",
     "{actor} joined the call" : "{actor} pievienojies zvanam",
@@ -38,7 +40,7 @@ OC.L10N.register(
     "{actor} set a password" : "{actor} iestatīja paroli",
     "You set a password" : "Jūs iestatījāt paroli",
     "{actor} removed the password" : "{actor} noņēma paroli",
-    "You removed the password" : "Jūs noņēmāt paroli",
+    "You removed the password" : "Tu noņēmi paroli",
     "{actor} added {user}" : "{actor} pievienoja {user}",
     "You joined the conversation" : "Jūs pievienojaties sarunai",
     "{actor} joined the conversation" : "{actor} pievienojās sarunai",
@@ -47,9 +49,11 @@ OC.L10N.register(
     "You left the conversation" : "Tu pameti sarunu",
     "{actor} left the conversation" : "{actor} pameta sarunu",
     "{actor} removed {user}" : "{actor} noņēma {user}",
-    "You removed {user}" : "Jūs noņēmāt {user}",
-    "{actor} removed you" : "{actor} jūs noņēma",
+    "You removed {user}" : "Tu noņēmi {user}",
+    "{actor} removed you" : "{actor} noņēma Tevi",
+    "You removed {federated_user}" : "Tu noņēmi {federated_user}",
     "You added {phone}" : "Tu pievienoji {phone}",
+    "You removed {phone}" : "Tu noņēmi {phone}",
     "{actor} promoted {user} to moderator" : "{actor} paaugstināja {user} par regulētāju",
     "You promoted {user} to moderator" : "Jūs paaugstinājāt {user} par regulētāju",
     "{actor} promoted you to moderator" : "{actor} paaugstināja jūs par regulētāju",
@@ -387,16 +391,19 @@ OC.L10N.register(
     "From" : "No",
     "To" : "Līdz",
     "Calendar" : "Kalendārs",
-    "Attendees" : "Apmeklētāji",
+    "Attendees" : "Dalībnieki",
     "Save" : "Saglabāt",
     "No results" : "Nav iznākuma",
     "Done" : "Pabeigts",
+    "Exit full screen (F)" : "Iziet no pilnekrāna (F)",
+    "Grid view" : "Režģa izkārtojums",
     "Waiting for others to join the call …" : "Gaidot citus pievienoties zvanam …",
     "You can invite others in the participant tab of the sidebar" : "Sānjoslā, dalībnieku cilnē var uzaicināt citus dalībniekus",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Sānjoslas dalībnieku cilnē varat uzaicināt citus lietotājus vai kopīgot šo saiti, lai uzaicinātu citus.",
     "Share this link to invite others!" : "Kopīgojiet šo saiti, lai uzaicinātu citus!",
-    "Copy link" : "Kopēt saiti",
+    "Copy link" : "Ievietot saiti starpliktuvē",
     "Mute audio" : "Izslēgt audio skaņu",
+    "None" : "Nav",
     "Disable video" : "Atspējot video",
     "Enable video" : "Iespējot video",
     "You" : "Jūs",
@@ -404,7 +411,7 @@ OC.L10N.register(
     "Collapse" : "Sakļaut",
     "Favorite" : "Izlasē",
     "Date:" : "Datums:",
-    "Hide details" : "Slēpt detaļas",
+    "Hide details" : "Paslēpt informāciju",
     "Show details" : "Rādīt informāciju",
     "Disable" : "Deaktivēt",
     "Enable" : "Iespējot",
@@ -435,8 +442,9 @@ OC.L10N.register(
     "Clear filter" : "Notīrīt atlasi",
     "Users" : "Lietotāji",
     "Groups" : "Grupas",
+    "Teams" : "Komandas",
     "Open conversations" : "Atvērt sarunas",
-    "None" : "Nav",
+    "Users and teams" : "Lietotāji un komandas",
     "Devices" : "Ierīces",
     "No audio" : "Nav audio",
     "Invalid path selected" : "Atlasīts nederīgs ceļš",
@@ -448,7 +456,7 @@ OC.L10N.register(
     "Go to file" : "Doties uz datni",
     "Translate" : "Tulkot",
     "Dismiss" : "Atmest",
-    "Contact" : "Kontakts",
+    "Contact" : "Kontaktpersona",
     "Today" : "Šodien",
     "Yesterday" : "Vakar",
     "_%n day ago_::_%n days ago_" : ["pirms %n dienām","pirms %n dienas","pirms %n dienām"],
@@ -463,12 +471,14 @@ OC.L10N.register(
     "Remove participant" : "Noņemt dalībnieku",
     "Demote from moderator" : "Pazemināt no regulētāja",
     "Promote to moderator" : "Paaugstināt par regulētāju",
-    "Remove" : "Izņemt",
+    "Remove" : "Noņemt",
     "Add users or groups" : "Add users or groups",
+    "Add users or teams" : "Pievienot lietotājus vai komandas",
+    "Add teams" : "Pievienot komandas",
     "Searching …" : "Meklē...",
     "Participants" : "Dalībnieki",
     "Chat" : "Tērzēt",
-    "Details" : "Detaļas",
+    "Details" : "Informācija",
     "From User" : "No lietotāja",
     "Load more results" : "Ielādēt vairāk iznākumu",
     "Projects" : "Projekti",
@@ -483,6 +493,7 @@ OC.L10N.register(
     "Start call" : "Sākt zvanu",
     "All tasks done!" : "Visi uzdevumi paveikti.",
     "_{done} of %n task_::_{done} of %n tasks_" : ["{done} no %n uzdevumiem","{done} no %n uzdevuma","{done} no %n uzdevumiem"],
+    "Default" : "Noklusējuma",
     "You are not allowed to enable screensharing" : "Nav ļauts iespējot ekrāna kopīgošanu",
     "No screensharing" : "Nav ekrāna kopīgošanas",
     "Screensharing options" : "Ekrāna kopīgošanas iespējas",
@@ -490,12 +501,10 @@ OC.L10N.register(
     "Screensharing requires the page to be loaded through HTTPS." : "Ekrāna kopīgošanai ir nepieciešams lapu ielādēt ar HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Ekrāna koplietošana darbojas tikai ar Firefox 52. vai jaunāku versiju.",
     "Screensharing extension is required to share your screen." : "Ir nepieciešams ekrāna kopīgošanas paplašinājums, lai kopīgotu savu ekrānu.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Lai koplietotu ekrānu, lūdzu, izmantojiet citu pārlūkprogrammu, piemēram, Firefox vai Chrome.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Lūgums izmantot citu pārlūku, piemēram, Firefox vai Chrome, lai kopīgotu savu ekrānu.",
     "An error occurred while starting screensharing." : "Ekrāna kopīgošanas uzsākšanas laikā atgadījās kļūda.",
     "Show your screen" : "Rādīt savu ekrānu",
     "Stop screensharing" : "Apturēt ekrāna kopīgošanu",
-    "Exit full screen (F)" : "Iziet no pilnekrāna (F)",
-    "Grid view" : "Režģa izkārtojums",
     "Start recording" : "Uzsākt ierakstīšanu",
     "Open Calendar" : "Atvērt kalendāru",
     "Would you like to delete this conversation?" : "Vai izdzēst šo sarunu?",
@@ -520,15 +529,14 @@ OC.L10N.register(
     "Search in conversation: {conversation}" : "Meklēt sarunā: {conversation}",
     "Error while sharing file" : "Kļūda datnes kopīgošanā",
     "Please reload the page." : "Lūdzu, atkārtoti ielādējiet lapu.",
-    "Default" : "Noklusējuma",
-    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tas aizņem vairāk laika, nekā paredzēts. Vai multivides atļaujas jau ir piešķirtas (vai noraidītas)? Ja atbilde ir “jā”, restartējiet pārlūkprogrammu, jo ir audio un video kļūme",
+    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tas aizņem vairāk laika, nekā paredzēts. Vai multivides atļaujas jau ir piešķirtas (vai noraidītas)? Ja atbilde ir “jā”, lūgums palaist savu pārlūku no jauna, jo ir skaņas un video atteice",
     "Access to microphone & camera is only possible with HTTPS" : "Piekļuve mikrofonam un kamerai ir iespējama izmantojot tikai HTTPS",
     "Please move your setup to HTTPS" : "Lūdzu, pārvietojiet iestatījumu uz HTTPS",
     "Access to microphone & camera was denied" : "Tika noraidīta piekļuve mikrofonam un kamerai",
-    "WebRTC is not supported in your browser" : "WebRTC netiek atbalstīta jūsu pārlūkprogrammā",
-    "Please use a different browser like Firefox or Chrome" : "Lūdzu, izmantojiet citu pārlūkprogrammu, piemēram Firefox vai Chrome",
+    "WebRTC is not supported in your browser" : "Pārlūkā netiek atbalstīts WebRTC",
+    "Please use a different browser like Firefox or Chrome" : "Lūgums izmantot citu pārlūku, piemēram, Firefox vai Chrome",
     "Error while accessing microphone & camera" : "Kļūda, piekļūstot mikrofonam un kamerai",
-    "The password is wrong. Try again." : "Nepareiza parole. Mēģiniet vēlreiz.",
+    "The password is wrong. Try again." : "Nepareiza parole. Jāmēģina vēlreiz.",
     "%s Talk on your mobile devices" : "%s Sarunas mobilajās ierīcēs",
     "Android app" : "Android lietotne",
     "iOS app" : "iOS lietotne",
@@ -539,7 +547,7 @@ OC.L10N.register(
     "Reports" : "Atskaites",
     "%s invited you to a conversation." : "%s uzaicināja jūs uz sarunu.",
     "You were invited to a conversation." : "Jūs uzaicinājāt uz sarunu.",
-    "Click the button below to join." : "Noklikšķiniet uz tālāk esošās pogas, lai pievienotos.",
+    "Click the button below to join." : "Jāklikšķina uz zemāk esošās pogas, lai pievienotos.",
     "Join »%s«" : "Pievienoties »%s«",
     "{user} invited you to a private conversation" : "{user} uzaicināja jūs uz privātu sarunu",
     "Close" : "Aizvērt"
