@@ -575,6 +575,7 @@ OC.L10N.register(
     "Back" : "Назад",
     "Cancel" : "Откажи",
     "Add participant \"{user}\"" : "Додади учесник \"{user}\"",
+    "Loading …" : "Се вчитува…",
     "From" : "Од",
     "To" : "До",
     "Calendar" : "Календар",
@@ -583,6 +584,10 @@ OC.L10N.register(
     "Search participants" : "Барај учесници",
     "No results" : "Нема резултати",
     "Done" : "Готово",
+    "Exit full screen (F)" : "Излез од цел екран (F)",
+    "Full screen (F)" : "Приказ на цел екран (F)",
+    "Speaker view" : "Поглед на тој што зборува",
+    "Grid view" : "Мрежа",
     "This conversation is read-only" : "Разговорот е само за читање",
     "Connecting …" : "Поврзување ...",
     "Waiting for others to join the call …" : "Чекање на останатите да се приклучат кон повикот ...",
@@ -594,6 +599,7 @@ OC.L10N.register(
     "Mute audio (M)" : "Занеми (Mute) го аудиото (М)",
     "Unmute audio" : "Одзанеми (Unmute) го аудиото",
     "Unmute audio (M)" : "Одзанеми (Unmute) го аудиото (М)",
+    "None" : "Ништо",
     "Access to camera was denied" : "Нема пристап до камерата",
     "Error while accessing camera" : "Грешка при пристап до камера",
     "You have been muted by a moderator" : "Администраторот ве занеми",
@@ -686,7 +692,6 @@ OC.L10N.register(
     "Users and groups" : "Корисници и групи",
     "Other sources" : "Други извори",
     "You are currently waiting in the lobby" : "Моментално чекате во лобито",
-    "None" : "Ништо",
     "Select microphone" : "Избери микрофон",
     "No microphone available" : "Нема микрофон",
     "Select camera" : "Избери камера",
@@ -877,11 +882,13 @@ OC.L10N.register(
     "Space bar" : "Празно место",
     "Push to talk or push to mute" : "Притисни за разговор или притисни за занемување",
     "Raise or lower hand" : "Крени или спушти рака",
+    "More actions" : "Повеќе акции",
     "Start call silently" : "Започни товок повик",
     "Start call" : "Повик",
     "You will be able to join the call only after a moderator starts it." : "Ќе може да се придружите на повикот само откако модераторот ќе го започне.",
     "Send a reaction" : "Испрати реакција",
     "React with {reaction}" : "Реагирај со {reaction}",
+    "Default" : "Стандардно",
     "_%n participant in call_::_%n participants in call_" : ["%n учесник во повикот","%n учесници во повикот"],
     "You are not allowed to enable screensharing" : "Не сте овластени да го овозможите споделување на екранот",
     "No screensharing" : "Нема споделување на екран",
@@ -911,10 +918,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Настана грешка при обидот за стартување на споделување на екранот.",
     "Show your screen" : "Прикажи го вашиот екран",
     "Stop screensharing" : "Запри споделување на екран",
-    "Exit full screen (F)" : "Излез од цел екран (F)",
-    "Full screen (F)" : "Приказ на цел екран (F)",
-    "Speaker view" : "Поглед на тој што зборува",
-    "Grid view" : "Мрежа",
     "Mute others" : "Занеми ги останатите",
     "Toggle full screen" : "Вклучи на цел екран",
     "Keep" : "Задржи",
@@ -984,7 +987,6 @@ OC.L10N.register(
     "Please reload the page." : "Превчитајте ја страницата.",
     "Do not disturb" : "Не вознемирувај",
     "Away" : "Далеку",
-    "Default" : "Стандардно",
     "Microphone {number}" : "Микрофон {number}",
     "Camera {number}" : "Камера {number}",
     "Speaker {number}" : "Зборуваат {number}",
