@@ -12,6 +12,7 @@ OC.L10N.register(
     "Dismiss notification" : "Hiq lajmërimin",
     "Accept" : "Prano",
     "Decline" : "Refuzo",
+    "New message" : "Mesazh i ri",
     "Open settings" : "Hap rregullimet",
     "error" : "gabim",
     "Conversations" : "Bisedat",
@@ -187,9 +188,11 @@ OC.L10N.register(
     "Save" : "Ruaj",
     "No results" : "Asnjë rezultat",
     "Done" : "U bë",
+    "Grid view" : "Pamje galeri",
     "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
     "Copy link" : "Kopjo linkun",
     "Mute audio" : "Mute audio",
+    "None" : "Asnjë",
     "Disable video" : "Çaktivizo video",
     "You" : "Ju",
     "Collapse" : "Tkurre",
@@ -216,7 +219,6 @@ OC.L10N.register(
     "Add to favorites" : "Shtoje tek të parapëlqyerat",
     "Users" : "Përdoruesit",
     "Groups" : "Grupet",
-    "None" : "Asnjë",
     "Devices" : "Pajisjet",
     "Upload" : "Ngarkoni",
     "Files" : "Skedarët",
@@ -241,6 +243,8 @@ OC.L10N.register(
     "Privacy" : "Privatësia",
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
     "Search" : "Kërko",
+    "More actions" : "Më tepër veprime ",
+    "Default" : "E paracaktuar",
     "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
     "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
@@ -248,7 +252,7 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
     "Show your screen" : "Shfaq ekranin tënd",
     "Stop screensharing" : "Ndalo ndarjen e ekranit",
-    "Grid view" : "Pamje galeri",
+    "Keep" : "Mbaje",
     "Submit" : "Dërgo",
     "User" : "Përdorues",
     "Password" : "Fjalëkalim",
@@ -262,7 +266,6 @@ OC.L10N.register(
     "Other" : "Tjetër",
     "Group" : "Grup",
     "Please reload the page." : "Ju lutemi, ringarkoni faqen.",
-    "Default" : "E paracaktuar",
     "Access to microphone & camera is only possible with HTTPS" : "Aksesi në mikrofon & kamera është i mundur vetëm me HTTPS",
     "Access to microphone & camera was denied" : "Aksesi tek mikrofoni & kamera u mohua",
     "WebRTC is not supported in your browser" : "WebRTC nuk mbështetet nga shfletuesi juaj.",
