@@ -1,10 +1,14 @@
 OC.L10N.register(
     "spreed",
     {
+    "Talk" : "Talk",
     "Guest" : "Mgeni",
     "Incoming call" : "Muito uanoingia",
+    "Message deleted by author" : "Message deleted by author",
     "Message deleted by you" : "Ujumbe umefutwa na wewe",
+    "System" : "Mfumo",
     "%s (guest)" : "%s (mgeni)",
+    "Talk to %s" : "Talk to %s",
     "File is too big" : "Faili ni kubwa mno",
     "Invalid file provided" : "Faili iliyotolewa si halali",
     "Invalid image" : "Taswira si halisi",
@@ -12,6 +16,7 @@ OC.L10N.register(
     "Say hi to your friends and colleagues!" : "Sema hi kwa marafiki zako na wenzako!",
     "Description" : "Maelezo",
     "Talk conversation for event" : "Mazungumzo ya Talk kwa tukio",
+    "Dismiss notification" : "Dismiss notification",
     "Accept" : "Kubali",
     "Decline" : "Kataa",
     "Reminder" : "Kikumbushio",
@@ -21,6 +26,7 @@ OC.L10N.register(
     "You missed a call from {user}" : "Ulikosa simu kutoka {user}",
     "You missed a group call in {call}" : "Ulikosa simu ya kikundi katika {call}",
     "Open settings" : "Mipangilio ya wazi",
+    "error" : "hitilafu",
     "Conversations" : "Mazungumzo",
     "Messages" : "Jumbe",
     "{user} in {conversation}" : "{user} katika {conversation}",
@@ -240,21 +246,31 @@ OC.L10N.register(
     "South Africa" : "Afrika ya kusini",
     "Zambia" : "Zambia",
     "Zimbabwe" : "Zimbabwe",
+    "Federation" : "Shirikisho",
     "Invalid date, date format must be YYYY-MM-DD" : "Tarehe batili, umbizo la tarehe lazima liwe YYYY-MM-DD",
     "Conversation not found" : "Mazungumzo hayapo",
     "Leave call" : "Acha simu",
+    "Everyone" : "Kila mmoja",
     "Saving …" : "Inahifadhi...",
+    "Saved!" : "Imehifadhiwa",
+    "Limit to groups" : "Limit to groups",
+    "Enabled" : "Washwa",
     "Disabled" : "Zima",
+    "State" : "State",
     "Name" : "Jina",
     "Permissions" : "Ruhusa",
     "Off" : "Imezimwa",
+    "Enable encryption" : "Enable encryption",
     "Pending" : "Inasubiri",
     "Error" : "Hitilafu",
+    "Active" : "Active",
     "Language" : "Lugha",
     "Country" : "Nchi",
     "Status" : "Wadhifa",
     "Created at" : "Imetengenezwa katika",
+    "Shared secret" : "Shared secret",
     "Recording consent" : "Idhini ya kurekodi",
+    "Error code" : "Error code",
     "{option1} and {option2}" : "{option1} and {option2}",
     "Failed" : "Imeshindwa",
     "OK" : "OK",
@@ -263,24 +279,36 @@ OC.L10N.register(
     "Reset" : "Pangilia upya",
     "Back" : "Rudi",
     "Cancel" : "Cancel",
+    "Now" : "Sasa",
+    "Invite {user}" : "Invite {user}",
     "Loading …" : "Inapakia",
     "From" : "Tangu/ kutoka",
     "To" : "Mpaka/ hadi",
     "Calendar" : "Kalenda",
     "Attendees" : "Wahudhuriaji",
     "Save" : "Hifadhi",
+    "No results" : "No results",
     "Done" : "Imefanyika",
+    "Raise hand" : "Inua mkono",
+    "Lower hand" : "Mkono wa chini",
+    "Grid view" : "Grid view",
     "Connecting …" : "Inaunganisha...",
     "Copy link" : "Nakili kiungio",
+    "None" : "Hakuna",
     "You" : "Wewe",
+    "Collapse" : "Collapse",
+    "Expand" : "Expand",
     "Drop your files to upload" : "Dondosha mafaili yako kupakia",
     "Scroll to bottom" : "Scroll to bottom",
     "Public conversation" : "Mazungumzo ya umma",
     "Favorite" : "Kipendwa",
     "Date:" : "Tarehe:",
+    "Note:" : "Kumbuka:",
     "Hide details" : "Ficha maelezo",
     "Show details" : "Onesha maelezo",
     "Unban" : "Unban",
+    "Disable" : "Zima",
+    "Enable" : "Wezesha",
     "Choose" : "Chagua",
     "Restricted" : "Imezuiliwa",
     "Meeting" : "Mkutano",
@@ -299,6 +327,7 @@ OC.L10N.register(
     "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation.",
     "Guest access" : "Ufikiaji wa mgeni",
     "Password protection" : "Password protection",
+    "Set a password" : "Weka nenosiri",
     "Resend invitations" : "Tuma mialiko upya",
     "Lock conversation" : "Funga mazungumzo",
     "Edit" : "Hariri",
@@ -310,10 +339,12 @@ OC.L10N.register(
     "Message preview will be disabled in conversation list and notifications" : "Message preview will be disabled in conversation list and notifications",
     "Require recording consent before joining call in this conversation" : "Require recording consent before joining call in this conversation",
     "Recording consent is required for all calls" : "Recording consent is required for all calls",
+    "Hello, {displayName}" : "Hello, {displayName}",
     "Create a new conversation" : "Tengeneza mazungumzo mapya",
     "Join open conversations" : "Jiunge mazungumzo ya wazi",
     "Unread mentions" : "Mitajo ambayo haijasomwa",
     "Create conversation" : "Tengeneza mazungumzo",
+    "Enter your name" : "Enter your name",
     "Log in" : "Ingia",
     "Mark as read" : "Weka alama kama iliyosomwa",
     "Mark as unread" : "Weka alama kama haijasomwa",
@@ -331,37 +362,50 @@ OC.L10N.register(
     "No search results" : "Hakuna matokeo ya utafutaji",
     "The meeting will start soon" : "Mkutano utaanza hivi karibuni",
     "This meeting is scheduled for {startTime}" : "Mkutano huu umepangwa kwa {startTime}",
-    "None" : "Hakuna",
+    "Devices" : "Vifaa",
     "The call might be recorded." : "Simu inaweza kuwa imerekodiwa",
-    "Call without notification" : "Call without notification",
     "Invalid path selected" : "Njia iliyochaguliwa si halali",
+    "Blur" : "Blur",
+    "Upload" : "Pakia",
     "Files" : "Mafaili",
     "Message sent" : "Ujumbe umetumwa",
     "Later today – {timeLocale}" : "Baadaye leo-{timeLocale}",
+    "Set reminder for later today" : "Set reminder for later today",
     "Tomorrow – {timeLocale}" : "Kesho-{timeLocale}",
+    "Set reminder for tomorrow" : "Set reminder for tomorrow",
     "This weekend – {timeLocale}" : "Wikendi-{timeLocale}",
+    "Set reminder for this weekend" : "Set reminder for this weekend",
     "Next week – {timeLocale}" : "Wiki ijayo-{timeLocale}",
+    "Set reminder for next week" : "Set reminder for next week",
     "Edited by {actor}" : "Imehaririwa na {actor}",
     "Reply" : "Jibu",
     "Set reminder" : "Weka ukumbusho",
     "Reply privately" : "Jibu kwa faragha",
     "Edit message" : "Hariri ujumbe",
+    "Copy message" : "Copy message",
+    "Go to thread" : "Go to thread",
     "Translate" : "Tafsiri",
+    "Set custom reminder" : "Set custom reminder",
     "Dismiss" : "Ondoa",
     "Copy translated text" : "Nakili maandishi yaliyotafsiriwa",
+    "Contact" : "Mawasiliano",
     "{stack} in {board}" : "{stack} katika {board}",
+    "Remove {fileName}" : "Remove {fileName}",
     "Poll" : "Kura ya maoni",
     "Today" : "Leo",
     "Yesterday" : "Jana",
     "Add participants" : "Ongeza washiriki",
     "Send message" : "Tuma ujumbe",
     "Send without notification" : "Tuma bila arifa",
-    "Cancel editing" : "Ghairi uhariri",
     "File to share" : "Faili la kushirikisha",
+    "Cancel editing" : "Ghairi uhariri",
     "Share from {nextcloud}" : "Shirikisha kutoka {nextcloud}",
     "Share from Files" : "Shirikisha kutoka katika mafaili",
     "Upload from device" : "Pakia kutoka katika kifaa",
     "Record voice message" : "Rekodi ujumbe wa sauti",
+    "End recording and send" : "End recording and send",
+    "Dismiss recording" : "Dismiss recording",
+    "Error while recording audio" : "Error while recording audio",
     "Talk recording from {time} ({conversation})" : "Talk inarekodi kutoka {time} ({conversation})",
     "Blank" : "Mabano",
     "Send" : "Tuma",
@@ -370,6 +414,7 @@ OC.L10N.register(
     "Settings" : "Mipangilio",
     "Multiple answers" : "Majibu mengi",
     "End poll" : "Maliza kura",
+    "guest" : "mgeni",
     "Remove group and members" : "Ndoa kundi na wanachama",
     "Remove team and members" : "Ondoa timu na wanachama",
     "Remove participant" : "Ondoa washiriki",
@@ -383,6 +428,8 @@ OC.L10N.register(
     "Search in {name}" : "Tafuta katika {name}",
     "No results found" : "Hakuna matokeo yaliyopatikana",
     "Load more results" : "Pakia matokeo zaidi",
+    "Recent threads" : "Recent threads",
+    "Projects" : "Projects",
     "No shared items" : "Hakuna vipengele vilivyoshirikiwa",
     "Select conversation" : "Chagua mazungumzo",
     "Appearance" : "Mwonekano",
@@ -391,13 +438,14 @@ OC.L10N.register(
     "Share my typing-status and show the typing-status of others" : "Share my typing-status and show the typing-status of others",
     "Keyboard shortcuts" : "Mikato ya keyboard",
     "Search" : "Tafuta",
+    "More actions" : "Vitendo zaidi",
+    "End call" : "Kata simu",
     "End call for everyone" : "Maliza simu kwa kila mtu",
     "Recording" : "Inarekodi",
     "The call has been running for one hour." : "The call has been running for one hour.",
     "Cancel recording start" : "Cancel recording start",
     "Stop recording" : "Simamisha kurekodi",
-    "Raise hand" : "Inua mkono",
-    "Lower hand" : "Mkono wa chini",
+    "Default" : "Chaguo msingi",
     "Start recording" : "Anza kurekodi",
     "Delete now" : "Futa sasa",
     "Keep" : "Weka",
@@ -405,6 +453,7 @@ OC.L10N.register(
     "Local time: {time}" : "Muda wa kawaida: {time}",
     "Search …" : "Tafuta...",
     "Join a conversation or start a new one" : "Jiunge na mazungumzo au anzisha mapya",
+    "Talk conversation" : "Mazungumzo ya Talk",
     "User" : "Mtumiaji",
     "Password" : "Nenosiri",
     "Login" : "Ingia",
@@ -412,6 +461,7 @@ OC.L10N.register(
     "Media" : "Midia",
     "Audio" : "Sauti",
     "Other" : "Mengine",
+    "Show all files" : "Show all files",
     "Group" : "Kundi",
     "Team" : "Timu",
     "You:" : "Wewe:",
@@ -424,6 +474,8 @@ OC.L10N.register(
     "Please reload the page." : "Tafadhali pakia ukurasa upya ",
     "Do not disturb" : "Acha kusumbua",
     "Away" : "Mbali",
+    "The password is wrong. Try again." : "The password is wrong. Try again.",
+    "iOS app" : "Programu ya iOS",
     "__language_name__" : "_lugha_jina_",
     "Call summary (%s)" : "Muhtasari wa simu (%s)",
     "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "The call summary bot posts an overview message after the call listing all participants and outlining tasks",
@@ -434,6 +486,7 @@ OC.L10N.register(
     "Agenda" : "Ajenda",
     "Call summary" : "Muhtasari wa simu",
     "Call summary - {title}" : "Muhtasari wa simu-{title}",
+    "Call without notification" : "Call without notification",
     "Close" : "Funga"
 },
 "nplurals=2; plural=(n != 1);");
