@@ -1,6 +1,7 @@
 OC.L10N.register(
     "spreed",
     {
+    "Incoming call" : "Kiruvchi qo'ng'iroq",
     "Message deleted by author" : "Xabar muallif tomonidan o'chirildi",
     "Deleted user" : "Deleted user",
     "System" : "System",
@@ -12,6 +13,9 @@ OC.L10N.register(
     "Talk conversation for event" : "Tadbir uchun suhbat",
     "Accept" : "Qabul qiling",
     "Decline" : "Rad etish",
+    "Reminder" : "Eslatma",
+    "Notification" : "Bildirishnomalar",
+    "error" : "Xatolik",
     "Everyone" : "Everyone",
     "Save changes" : "Save changes",
     "Saving …" : "Saqlanmoqda...",
@@ -20,24 +24,25 @@ OC.L10N.register(
     "Off" : "Oʻchirilgan",
     "Enable encryption" : "Enable encryption",
     "Pending" : "Pending",
-    "Error" : "Error",
+    "Error" : "Xatolik",
     "Language" : "Language",
     "Status" : "Status",
-    "OK" : "OK",
+    "OK" : "Yaxshi",
     "Checking …" : "Checking …",
     "Federated user" : "Korporativ foydalanuvchi",
     "Confirm" : "Confirm",
     "Reset" : "Qayta tiklash",
     "Back" : "Orqaga",
-    "Cancel" : "Cancel",
-    "No upcoming events" : "Kelgusi tadbirlar yo'q",
+    "Cancel" : "Bekor qilish",
     "From" : "Dan",
     "To" : "Gacha",
     "Calendar" : "Calendar",
     "Attendees" : "Ishtirokchilar",
-    "Save" : "Save",
+    "Save" : "Saqlash",
     "Done" : "Done",
+    "Grid view" : "To‘r ko‘rinishi",
     "Copy link" : "Havolani nusxalash",
+    "None" : "Yo'q",
     "Favorite" : "Favorite",
     "Date:" : "Sana:",
     "Hide details" : "Tafsilotlarni yashirish",
@@ -46,8 +51,8 @@ OC.L10N.register(
     "Enable" : "Enable",
     "Choose" : "Choose",
     "Restricted" : "Cheklangan",
-    "Personal" : "Personal",
     "Meeting" : "Uchrashuv",
+    "Personal" : "Personal",
     "No" : "No",
     "Yes" : "Yes",
     "Delete conversation" : "Delete conversation",
@@ -56,42 +61,43 @@ OC.L10N.register(
     "_%n week_::_%n weeks_" : ["%n hafta"],
     "Password protection" : "Parol himoyasi",
     "Edit" : "Tahrirlash",
-    "Delete" : "Delete",
+    "Delete" : "O'chirish",
     "Notifications" : "Notifications",
+    "Create a new conversation" : "Yangi suhbat yarating",
     "Log in" : "Kirish",
     "Remove from favorites" : "Sevimlilardan olib tashlang",
     "Add to favorites" : "Sevimlilarga qo'shing",
-    "Create a new conversation" : "Yangi suhbat yarating",
     "Users" : "Users",
     "Groups" : "Groups",
     "No search results" : "Qidiruv natijalari yo‘q",
-    "None" : "None",
     "Select a device" : "Qurilmani tanlang",
-    "Upload" : "Upload",
-    "Files" : "Files",
+    "Upload" : "Yuklash",
+    "Files" : "Fayllar",
     "Reply" : "Javob bering",
     "Translate" : "Tarjima",
     "Dismiss" : "Dismiss",
     "Contact" : "Aloqa",
+    "Remove {fileName}" : " {fileName} ni o'chirish",
     "Today" : "Today",
     "Yesterday" : "Kecha",
     "Add emoji" : "Emoji qo'shing",
     "Upload from device" : "Qurilmadan yuklash",
     "Send" : "Send",
-    "Settings" : "Settings",
-    "Remove" : "Remove",
+    "Settings" : "Sozlamalar",
+    "Remove" : "O'chirish",
     "Searching …" : "Qidirilmoqda …",
-    "Search in {name}" : " {name}ni qidirish",
     "Details" : "Details",
+    "Search in {name}" : " {name}ni qidirish",
     "No results found" : "Hech qanday natija topilmadi",
     "Load more results" : "Ko'proq natijalarni yuklang",
     "Projects" : "Loyihalar",
     "Select conversation" : "Suhbatni tanlang",
     "Appearance" : "Tashqi ko'rinish",
-    "Search" : "Search",
-    "Grid view" : "To‘r ko‘rinishi",
+    "Search" : "Qidirish",
+    "More actions" : "Ko'proq harakatlar",
     "Password" : "Password",
     "Login" : "Login",
+    "Client ID" : "Mijoz identifikatori",
     "Audio" : "Audio",
     "Other" : "Boshqa",
     "Show all files" : "Barcha fayllarni ko'rsatish",
@@ -104,6 +110,6 @@ OC.L10N.register(
     "Tasks" : "Tasks",
     "Notes" : "Notes",
     "Reports" : "Hisobotlar",
-    "Close" : "Close"
+    "Close" : "Yopish"
 },
 "nplurals=1; plural=0;");
