@@ -2,30 +2,15 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2020 Julien Veyssier <eneiluj@posteo.net>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk;
 
 use OC\Authentication\Token\IProvider as IAuthTokenProvider;
-use OC\Authentication\Token\IToken;
 use OCA\Talk\Chat\ChatManager;
+use OCA\Talk\Events\AAttendeeRemovedEvent;
 use OCA\Talk\Exceptions\ImpossibleToKillException;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\RoomNotFoundException;
@@ -33,6 +18,7 @@ use OCA\Talk\Exceptions\WrongPermissionsException;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Service\ParticipantService;
 use OCP\AppFramework\Utility\ITimeFactory;
+use OCP\Authentication\Token\IToken;
 use OCP\DB\Exception;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IAvatarManager;
@@ -43,55 +29,34 @@ use OCP\IUserManager;
 use OCP\Security\ISecureRandom;
 use Psr\Log\LoggerInterface;
 
+/**
+ * @psalm-import-type TalkMatterbridge from ResponseDefinitions
+ * @psalm-import-type TalkMatterbridgeProcessState from ResponseDefinitions
+ */
 class MatterbridgeManager {
 	public const BRIDGE_BOT_USERID = 'bridge-bot';
 
-	private IDBConnection $db;
-	private IConfig $config;
-	private IURLGenerator $urlGenerator;
-	private IUserManager $userManager;
-	private Manager $manager;
-	private ParticipantService $participantService;
-	private ChatManager $chatManager;
-	private IAuthTokenProvider $tokenProvider;
-	private ISecureRandom $random;
-	private IAvatarManager $avatarManager;
-	private LoggerInterface $logger;
-	private ITimeFactory $timeFactory;
-
 	public function __construct(
-		IDBConnection $db,
-		IConfig $config,
-		IURLGenerator $urlGenerator,
-		IUserManager $userManager,
-		Manager $manager,
-		ParticipantService $participantService,
-		ChatManager $chatManager,
-		IAuthTokenProvider $tokenProvider,
-		ISecureRandom $random,
-		IAvatarManager $avatarManager,
-		LoggerInterface $logger,
-		ITimeFactory $timeFactory,
+		private IDBConnection $db,
+		private IConfig $config,
+		private IURLGenerator $urlGenerator,
+		private IUserManager $userManager,
+		private Manager $manager,
+		private ParticipantService $participantService,
+		private ChatManager $chatManager,
+		private IAuthTokenProvider $tokenProvider,
+		private ISecureRandom $random,
+		private IAvatarManager $avatarManager,
+		private LoggerInterface $logger,
+		private ITimeFactory $timeFactory,
 	) {
-		$this->avatarManager = $avatarManager;
-		$this->db = $db;
-		$this->config = $config;
-		$this->urlGenerator = $urlGenerator;
-		$this->userManager = $userManager;
-		$this->manager = $manager;
-		$this->participantService = $participantService;
-		$this->chatManager = $chatManager;
-		$this->tokenProvider = $tokenProvider;
-		$this->random = $random;
-		$this->logger = $logger;
-		$this->timeFactory = $timeFactory;
 	}
 
 	/**
 	 * Get bridge information for a specific room
 	 *
 	 * @param Room $room the room
-	 * @return array decoded json bridge information
+	 * @return TalkMatterbridge
 	 */
 	public function getBridgeOfRoom(Room $room): array {
 		return $this->getBridgeFromDb($room);
@@ -101,7 +66,7 @@ class MatterbridgeManager {
 	 * Get bridge process information for a specific room
 	 *
 	 * @param Room $room the room
-	 * @return array process state and log
+	 * @return TalkMatterbridgeProcessState process state and log
 	 */
 	public function getBridgeProcessState(Room $room): array {
 		$bridge = $this->getBridgeFromDb($room);
@@ -134,7 +99,7 @@ class MatterbridgeManager {
 	 * @param string $userId
 	 * @param bool $enabled desired state of the bridge
 	 * @param array $parts parts of the bridge (what it connects to)
-	 * @return array bridge state
+	 * @return TalkMatterbridgeProcessState
 	 */
 	public function editBridgeOfRoom(Room $room, string $userId, bool $enabled, array $parts = []): array {
 		$currentBridge = $this->getBridgeOfRoom($room);
@@ -196,12 +161,12 @@ class MatterbridgeManager {
 		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
 			$bridge = [
-				'enabled' => (bool) $row['enabled'],
-				'pid' => (int) $row['pid'],
+				'enabled' => (bool)$row['enabled'],
+				'pid' => (int)$row['pid'],
 				'parts' => json_decode($row['json_values'], true),
 			];
 			try {
-				$room = $this->manager->getRoomById((int) $row['room_id']);
+				$room = $this->manager->getRoomById((int)$row['room_id']);
 			} catch (RoomNotFoundException $e) {
 				continue;
 			}
@@ -264,6 +229,7 @@ class MatterbridgeManager {
 			'login' => $botInfo['id'],
 			'password' => $botInfo['password'],
 			'channel' => $room->getToken(),
+			'skiptls' => true,
 		];
 		$bridge['parts'][] = $localPart;
 		return $bridge;
@@ -297,7 +263,7 @@ class MatterbridgeManager {
 		try {
 			$this->participantService->getParticipant($room, self::BRIDGE_BOT_USERID, false);
 			if (!$isBridgeEnabled) {
-				$this->participantService->removeUser($room, $botUser, Room::PARTICIPANT_REMOVED);
+				$this->participantService->removeUser($room, $botUser, AAttendeeRemovedEvent::REASON_REMOVED);
 			}
 		} catch (ParticipantNotFoundException $e) {
 			if ($isBridgeEnabled) {
@@ -377,10 +343,13 @@ class MatterbridgeManager {
 					$serverUrl = $part['server'];
 				} else {
 					$serverUrl = preg_replace('/\/+$/', '', $this->urlGenerator->getAbsoluteURL(''));
-					$content .= "	SeparateDisplayName = true" ."\n";
+					$content .= '	SeparateDisplayName = true' . "\n";
 					// TODO remove that
 					//$serverUrl = preg_replace('/https:/', 'http:', $serverUrl);
 				}
+				if ($part['skiptls']) {
+					$content .= '	SkipTLSVerify = true' . "\n";
+				}
 				$content .= sprintf('	Server = "%s"', $serverUrl) . "\n";
 				$content .= sprintf('	Login = "%s"', $part['login']) . "\n";
 				$content .= sprintf('	Password = "%s"', $part['password']) . "\n";
@@ -416,7 +385,7 @@ class MatterbridgeManager {
 				$content .= '	RemoteNickFormat = "[{PROTOCOL}] <{NICK}> "' . "\n\n";
 			} elseif ($type === 'rocketchat') {
 				// include # in channel
-				if (!preg_match('/^#/', $part['channel'])) {
+				if (!str_starts_with($part['channel'], '#')) {
 					$bridge['parts'][$k]['channel'] = '#' . $part['channel'];
 				}
 				$content .= sprintf('[%s.%s]', $type, $k) . "\n";
@@ -430,7 +399,7 @@ class MatterbridgeManager {
 				$content .= '	RemoteNickFormat = "[{PROTOCOL}] <{NICK}> "' . "\n\n";
 			} elseif ($type === 'slack') {
 				// do not include # in channel
-				if (strpos($part['channel'], '#') === 0) {
+				if (str_starts_with($part['channel'], '#')) {
 					$bridge['parts'][$k]['channel'] = ltrim($part['channel'], '#');
 				}
 				$content .= sprintf('[%s.%s]', $type, $k) . "\n";
@@ -439,7 +408,7 @@ class MatterbridgeManager {
 				$content .= '	RemoteNickFormat = "[{PROTOCOL}] <{NICK}> "' . "\n\n";
 			} elseif ($type === 'discord') {
 				// do not include # in channel
-				if (strpos($part['channel'], '#') === 0) {
+				if (str_starts_with($part['channel'], '#')) {
 					$bridge['parts'][$k]['channel'] = ltrim($part['channel'], '#');
 				}
 				$content .= sprintf('[%s.%s]', $type, $k) . "\n";
@@ -460,7 +429,7 @@ class MatterbridgeManager {
 				$content .= '	RemoteNickFormat = "[{PROTOCOL}] <{NICK}> "' . "\n\n";
 			} elseif ($type === 'irc') {
 				// include # in channel
-				if (!preg_match('/^#/', $part['channel'])) {
+				if (!str_starts_with($part['channel'], '#')) {
 					$bridge['parts'][$k]['channel'] = '#' . $part['channel'];
 				}
 				$content .= sprintf('[%s.%s]', $type, $k) . "\n";
@@ -554,7 +523,7 @@ class MatterbridgeManager {
 	private function checkBridgeProcess(Room $room, array $bridge, bool $relaunch = true): int {
 		$pid = 0;
 
-		if (isset($bridge['pid']) && (int) $bridge['pid'] !== 0) {
+		if (isset($bridge['pid']) && (int)$bridge['pid'] !== 0) {
 			// config : there is a PID stored
 			$isRunning = $this->isRunning($bridge['pid']);
 			// if bridge running and enabled is false : kill it
@@ -588,7 +557,7 @@ class MatterbridgeManager {
 				// config : no PID stored
 				// config : enabled => launch it
 				$pid = $this->launchMatterbridge($room);
-				$this->logger->info('Launch process, PID is '.$pid);
+				$this->logger->info('Launch process, PID is ' . $pid);
 			}
 		} else {
 			$this->logger->info('No PID defined in config AND bridge disabled in config : doing nothing');
@@ -711,7 +680,7 @@ class MatterbridgeManager {
 
 		$cmdResult = $this->runCommand($cmd);
 		if (!is_null($cmdResult) && $cmdResult['return_code'] === 0 && is_numeric($cmdResult['stdout'] ?? 0)) {
-			return (int) $cmdResult['stdout'];
+			return (int)$cmdResult['stdout'];
 		}
 		return 0;
 	}
@@ -731,7 +700,7 @@ class MatterbridgeManager {
 				if (preg_match('/matterbridge/i', $l)) {
 					$items = preg_split('/\s+/', $l);
 					if (count($items) > 1 && is_numeric($items[1])) {
-						$runningPidList[] = (int) $items[1];
+						$runningPidList[] = (int)$items[1];
 					}
 				}
 			}
@@ -759,7 +728,7 @@ class MatterbridgeManager {
 
 		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
-			$expectedPidList[] = (int) $row['pid'];
+			$expectedPidList[] = (int)$row['pid'];
 		}
 		$result->closeCursor();
 
@@ -800,7 +769,7 @@ class MatterbridgeManager {
 				foreach ($lines as $l) {
 					$items = preg_split('/\s+/', $l);
 					if (count($items) > 1 && is_numeric($items[1])) {
-						$lPid = (int) $items[1];
+						$lPid = (int)$items[1];
 						if ($lPid === $pid) {
 							return true;
 						}
@@ -858,7 +827,7 @@ class MatterbridgeManager {
 	 * Get bridge information for one room
 	 *
 	 * @param Room $room the room
-	 * @return array decoded json array
+	 * @return TalkMatterbridge
 	 */
 	private function getBridgeFromDb(Room $room): array {
 		$roomId = $room->getId();
@@ -875,8 +844,8 @@ class MatterbridgeManager {
 		$pid = 0;
 		$jsonValues = '[]';
 		if ($row = $result->fetch()) {
-			$pid = (int) $row['pid'];
-			$enabled = ((int) $row['enabled'] === 1);
+			$pid = (int)$row['pid'];
+			$enabled = ((int)$row['enabled'] === 1);
 			$jsonValues = $row['json_values'];
 		}
 		$result->closeCursor();
